@@ -170,7 +170,7 @@ def parse_GFF_attribute_string( attrStr, extra_return_first_value=False ):
 
 class GFF_Reader( FileOrSequence ):
 
-   """Parser a GFF file
+   """Parse a GFF file
    
    Pass the constructor either a file name or an iterator of lines of a 
    GFF files. If a file name is specified, it may refer to a gzip compressed
@@ -179,6 +179,11 @@ class GFF_Reader( FileOrSequence ):
    Iterating over the object then yields GenomicFeature objects.
    """
    
+   def __init__( self, filename_or_sequence, end_included=False ):
+      FileOrSequence.__init__( self, filename_or_sequence )
+      self.end_included = end_included
+   
+   
    def __iter__( self ):
       for line in FileOrSequence.__iter__( self ):
          if line.startswith( '#' ):
@@ -186,8 +191,11 @@ class GFF_Reader( FileOrSequence ):
          ( seqname, source, feature, start, end, score, 
             strand, frame, attributeStr ) = line.split( "\t", 8 )   
          ( attr, name ) = parse_GFF_attribute_string( attributeStr, True )
-         f = GenomicFeature( name, feature,
-             GenomicInterval( seqname, int(start)-1, int(end), strand ) )
+         if self.end_included:
+            iv = GenomicInterval( seqname, int(start)-1, int(end)-1, strand )
+         else:
+            iv = GenomicInterval( seqname, int(start)-1, int(end), strand )
+         f = GenomicFeature( name, feature, iv )
          if score != ".":
             score = int( score )
          if frame != ".":
@@ -527,8 +535,8 @@ def pair_SAM_alignments( alignments ):
             read1.read.name )
       if not ( read1.mate_start == read2.iv.start_as_pos and 
             read2.mate_start == read1.iv.start_as_pos ):
-         warnings.warn( "Read pair " + readA.read.name +
-            " show inconsitency between 'iv' and 'mate_start' values" )
+         warnings.warn( "Read pair " + read1.read.name +
+            " show inconsistency between 'iv' and 'mate_start' values" )
       return ( read1, read2 )
 
    def process_single_read( read ):
