@@ -20,16 +20,24 @@ def count_reads_in_features( sam_filename, gff_filename, stranded,
       
    features = HTSeq.GenomicArrayOfSets( [], stranded )     
    counts = {}
+
+   # Try to open samfile to fail early in case it is not there
+   open( sam_filename ).close()
       
    for f in HTSeq.GFF_Reader( gff_filename ):
       if f.iv.chrom not in features.step_vectors.keys():
          features.add_chrom( f.iv.chrom )
       if f.type == feature_type:
          try:
-            features.add_value( f.attr[ id_attribute ], f.iv )
+            feature_id = f.attr[ id_attribute ]
          except KeyError:
             sys.exit( "Feature %s does not contain a '%s' attribute" % 
                ( f.name, id_attribute ) )
+         if stranded and f.iv.strand == ".":
+            sys.exit( "Feature %s at %s does not have strand information but you are "
+               "running htseq-count in stranded mode. Use '--stranded=no'." % 
+               ( f.name, f.iv ) )
+         features.add_value( feature_id, f.iv )
          counts[ f.attr[ id_attribute ] ] = 0
          
    if len( counts ) == 0 and not quiet:
@@ -90,9 +98,10 @@ def count_reads_in_features( sam_filename, gff_filename, stranded,
          else:
             counts[ list(fs)[0] ] += 1
       except UnknownChrom:
-         sys.stderr.write( ( "Warning: Skipping read '%s', aligned to %s, because " +
-            "chromosome '%s' did not appear in the GFF file.\n" ) % 
-            ( r.read.name, r.iv, r.iv.chrom ) )
+         rr = r if not pe_mode else r[0]
+         sys.stderr.write( ( "Warning: Skipping read '%s', because chromosome " +
+            "'%s', to which it has been aligned, did not appear in the GFF file.\n" ) % 
+            ( rr.read.name, iv.chrom ) )
 
       i += 1
       if i % 100000 == 0 and not quiet:
